@@ -4,9 +4,9 @@ use crate::flags::{Display, Flags, HyperlinkOption, Layout};
 use crate::git_theme::GitTheme;
 use crate::icon::Icons;
 use crate::meta::name::DisplayOption;
-use crate::meta::{FileType, Meta};
+use crate::meta::{FileType, Meta, OwnerCache};
 use std::collections::HashMap;
-use term_grid::{Alignment, Cell, Direction, Filling, Grid, GridOptions};
+use term_grid::{Cell, Direction, Filling, Grid, GridOptions};
 use terminal_size::terminal_size;
 use unicode_width::UnicodeWidthStr;
 
@@ -23,10 +23,12 @@ pub fn grid(
     git_theme: &GitTheme,
 ) -> String {
     let term_width = terminal_size().map(|(w, _)| w.0 as usize);
+    let owner_cache = OwnerCache::default();
 
     inner_display_grid(
         &DisplayOption::None,
         metas,
+        &owner_cache,
         flags,
         colors,
         icons,
@@ -57,8 +59,11 @@ pub fn tree(
         }
     }
 
+    let owner_cache = OwnerCache::default();
+
     for cell in inner_display_tree(
         metas,
+        &owner_cache,
         flags,
         colors,
         icons,
@@ -77,6 +82,7 @@ pub fn tree(
 fn inner_display_grid(
     display_option: &DisplayOption,
     metas: &[Meta],
+    owner_cache: &OwnerCache,
     flags: &Flags,
     colors: &Colors,
     icons: &Icons,
@@ -109,14 +115,15 @@ fn inner_display_grid(
         // Maybe skip showing the directory meta now; show its contents later.
         if skip_dirs
             && (matches!(meta.file_type, FileType::Directory { .. })
-                || (matches!(meta.file_type, FileType::SymLink { is_dir: true })
-                    && flags.layout != Layout::OneLine))
+                || (matches!(meta.file_type, FileType::SymLink { is_dir: true }))
+                    && flags.blocks.0.len() == 1)
         {
             continue;
         }
 
         let blocks = get_output(
             meta,
+            owner_cache,
             colors,
             icons,
             git_theme,
@@ -130,7 +137,6 @@ fn inner_display_grid(
             cells.push(Cell {
                 width: get_visible_width(&block, flags.hyperlink == HyperlinkOption::Always),
                 contents: block,
-                alignment: Alignment::Left,
             });
         }
     }
@@ -161,7 +167,7 @@ fn inner_display_grid(
         output += &grid.fit_into_columns(flags.blocks.0.len()).to_string();
     }
 
-    let should_display_folder_path = should_display_folder_path(depth, metas, flags);
+    let should_display_folder_path = should_display_folder_path(depth, metas);
 
     // print the folder content
     for meta in metas {
@@ -177,6 +183,7 @@ fn inner_display_grid(
             output += &inner_display_grid(
                 &display_option,
                 content,
+                owner_cache,
                 flags,
                 colors,
                 icons,
@@ -217,7 +224,6 @@ fn add_header(flags: &Flags, cells: &[Cell], grid: &mut Grid) {
         grid.add(Cell {
             width: widths[idx],
             contents: underlined_header,
-            alignment: Alignment::Left,
         });
     }
 }
@@ -225,6 +231,7 @@ fn add_header(flags: &Flags, cells: &[Cell], grid: &mut Grid) {
 #[allow(clippy::too_many_arguments)]
 fn inner_display_tree(
     metas: &[Meta],
+    owner_cache: &OwnerCache,
     flags: &Flags,
     colors: &Colors,
     icons: &Icons,
@@ -250,6 +257,7 @@ fn inner_display_tree(
 
         for block in get_output(
             meta,
+            owner_cache,
             colors,
             icons,
             git_theme,
@@ -261,7 +269,6 @@ fn inner_display_tree(
             cells.push(Cell {
                 width: get_visible_width(&block, flags.hyperlink == HyperlinkOption::Always),
                 contents: block,
-                alignment: Alignment::Left,
             });
         }
 
@@ -279,6 +286,7 @@ fn inner_display_tree(
 
             cells.extend(inner_display_tree(
                 content,
+                owner_cache,
                 flags,
                 colors,
                 icons,
@@ -293,7 +301,7 @@ fn inner_display_tree(
     cells
 }
 
-fn should_display_folder_path(depth: usize, metas: &[Meta], flags: &Flags) -> bool {
+fn should_display_folder_path(depth: usize, metas: &[Meta]) -> bool {
     if depth > 0 {
         true
     } else {
@@ -301,8 +309,7 @@ fn should_display_folder_path(depth: usize, metas: &[Meta], flags: &Flags) -> bo
             .iter()
             .filter(|x| {
                 matches!(x.file_type, FileType::Directory { .. })
-                    || (matches!(x.file_type, FileType::SymLink { is_dir: true })
-                        && flags.layout != Layout::OneLine)
+                    || (matches!(x.file_type, FileType::SymLink { is_dir: true }))
             })
             .count();
 
@@ -317,6 +324,7 @@ fn display_folder_path(meta: &Meta) -> String {
 #[allow(clippy::too_many_arguments)]
 fn get_output(
     meta: &Meta,
+    owner_cache: &OwnerCache,
     colors: &Colors,
     icons: &Icons,
     git_theme: &GitTheme,
@@ -360,11 +368,11 @@ fn get_output(
                 ]);
             }
             Block::User => block_vec.push(match &meta.owner {
-                Some(owner) => owner.render_user(colors, flags),
+                Some(owner) => owner.render_user(colors, owner_cache, flags),
                 None => colorize_missing("?"),
             }),
             Block::Group => block_vec.push(match &meta.owner {
-                Some(owner) => owner.render_group(colors, flags),
+                Some(owner) => owner.render_group(colors, owner_cache, flags),
                 None => colorize_missing("?"),
             }),
             Block::Context => block_vec.push(match &meta.access_control {
@@ -431,7 +439,8 @@ fn get_visible_width(input: &str, hyperlink: bool) -> usize {
 
         let m_pos = s.find('m');
         if let Some(len) = m_pos {
-            nb_invisible_char += len
+            // len points to the 'm' character, we must include 'm' to invisible characters
+            nb_invisible_char += len + 1;
         }
     }
 
@@ -441,11 +450,13 @@ fn get_visible_width(input: &str, hyperlink: bool) -> usize {
 
             let m_pos = s.find("\x1B\x5C");
             if let Some(len) = m_pos {
-                nb_invisible_char += len
+                // len points to the '\x1B' character, we must include both '\x1B' and '\x5C' to invisible characters
+                nb_invisible_char += len + 2
             }
         }
     }
 
+    // `UnicodeWidthStr::width` counts all unicode characters including escape '\u{1b}' and hyperlink '\x1B'
     UnicodeWidthStr::width(input) - nb_invisible_char
 }
 
@@ -490,13 +501,13 @@ fn get_padding_rules(metas: &[Meta], flags: &Flags) -> HashMap<Block, usize> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::Config;
     use crate::app::Cli;
     use crate::color;
     use crate::color::Colors;
     use crate::flags::{HyperlinkOption, IconOption, IconTheme as FlagTheme, PermissionFlag};
     use crate::icon::Icons;
     use crate::meta::{FileType, Name};
-    use crate::Config;
     use crate::{flags, sort};
     use assert_fs::prelude::*;
     use clap::Parser;
@@ -740,7 +751,7 @@ mod tests {
                 .lines()
                 .nth(i)
                 .unwrap()
-                .split(|c| c == 'K' || c == 'B')
+                .split(['K', 'B'])
                 .next()
                 .unwrap()
                 .len()
@@ -916,23 +927,20 @@ mod tests {
         const NO: bool = false;
 
         assert_eq!(
-            should_display_folder_path(0, &[file.clone()], &Flags::default()),
+            should_display_folder_path(0, &[file.clone()]),
             YES // doesn't matter since there is no folder
         );
+        assert_eq!(should_display_folder_path(0, &[dir.clone()]), NO);
         assert_eq!(
-            should_display_folder_path(0, &[dir.clone()], &Flags::default()),
-            NO
-        );
-        assert_eq!(
-            should_display_folder_path(0, &[file.clone(), dir.clone()], &Flags::default()),
+            should_display_folder_path(0, &[file.clone(), dir.clone()]),
             YES
         );
         assert_eq!(
-            should_display_folder_path(0, &[dir.clone(), dir.clone()], &Flags::default()),
+            should_display_folder_path(0, &[dir.clone(), dir.clone()]),
             YES
         );
         assert_eq!(
-            should_display_folder_path(0, &[file.clone(), file.clone()], &Flags::default()),
+            should_display_folder_path(0, &[file.clone(), file.clone()]),
             YES // doesn't matter since there is no folder
         );
 
@@ -957,43 +965,18 @@ mod tests {
         std::os::unix::fs::symlink("dir", &link_path).unwrap();
         let link = Meta::from_path(&link_path, false, PermissionFlag::Rwx).unwrap();
 
-        let grid_flags = Flags {
-            layout: Layout::Grid,
-            ..Flags::default()
-        };
-
-        let oneline_flags = Flags {
-            layout: Layout::OneLine,
-            ..Flags::default()
-        };
-
         const YES: bool = true;
         const NO: bool = false;
 
+        assert_eq!(should_display_folder_path(0, &[link.clone()]), NO);
+
         assert_eq!(
-            should_display_folder_path(0, &[link.clone()], &grid_flags),
-            NO
-        );
-        assert_eq!(
-            should_display_folder_path(0, &[link.clone()], &oneline_flags),
-            YES // doesn't matter since this link will be expanded as a directory
+            should_display_folder_path(0, &[file.clone(), link.clone()]),
+            YES
         );
 
         assert_eq!(
-            should_display_folder_path(0, &[file.clone(), link.clone()], &grid_flags),
-            YES
-        );
-        assert_eq!(
-            should_display_folder_path(0, &[file.clone(), link.clone()], &oneline_flags),
-            YES // doesn't matter since this link will be expanded as a directory
-        );
-
-        assert_eq!(
-            should_display_folder_path(0, &[dir.clone(), link.clone()], &grid_flags),
-            YES
-        );
-        assert_eq!(
-            should_display_folder_path(0, &[dir.clone(), link.clone()], &oneline_flags),
+            should_display_folder_path(0, &[dir.clone(), link.clone()]),
             YES
         );
 
